==> haskell-wai-logger-2.2.7-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-logger.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-logger
version: 2.2.7
id: wai-logger-2.2.7-9GHIezeKe8i1PVwZYmIpR4
key: wai-logger-2.2.7-9GHIezeKe8i1PVwZYmIpR4
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: A logging system for WAI
description:
    A logging system for WAI
category: Web, Yesod
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.Wai.Logger
hidden-modules: Network.Wai.Logger.Apache Network.Wai.Logger.IP
                Network.Wai.Logger.IORef
abi: dc692e4c0b740de383df1c145661dbc3
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wai-logger-2.2.7
library-dirs: /usr/lib/ghc-8.0.1/site-local/wai-logger-2.2.7
data-dir: /usr/share/arm-linux-ghc-8.0.1/wai-logger-2.2.7
hs-libraries: HSwai-logger-2.2.7-9GHIezeKe8i1PVwZYmIpR4
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    byteorder-1.0.4-BbL4c17EpZrL9PcZm0xys9 bytestring-0.10.8.1
    case-insensitive-1.2.0.6-I0Jt0nwhqya3cOqVnbSTZ9
    fast-logger-2.4.6-Ko6hpzrohxlG6RfUnE9VNU
    http-types-0.9.1-COSfHHdOet5Sq6KAE7lWN
    network-2.6.2.1-Li0aefQhyJzUSpQ0fLiXL unix-2.7.2.0
    unix-time-0.3.6-6bZ4vlHgZbL8E5DKeI2fRH
    wai-3.2.1.1-FhGbGXgEdLG73fMsfll74t
haddock-interfaces: /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
haddock-html: /usr/share/doc/haskell-wai-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-logger-2.3.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-logger.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-logger
version: 2.3.0
id: wai-logger-2.3.0-BPT47WMnBXb3s3jR5ivCpm
key: wai-logger-2.3.0-BPT47WMnBXb3s3jR5ivCpm
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: A logging system for WAI
description:
    A logging system for WAI
category: Web, Yesod
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.Wai.Logger
hidden-modules: Network.Wai.Logger.Apache Network.Wai.Logger.IP
                Network.Wai.Logger.IORef
abi: 844742bb692138e4d6a7519810f13706
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/wai-logger-2.3.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/wai-logger-2.3.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/wai-logger-2.3.0
hs-libraries: HSwai-logger-2.3.0-BPT47WMnBXb3s3jR5ivCpm
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    byteorder-1.0.4-BbL4c17EpZrL9PcZm0xys9 bytestring-0.10.8.1
    case-insensitive-1.2.0.6-I0Jt0nwhqya3cOqVnbSTZ9
    fast-logger-2.4.6-Ko6hpzrohxlG6RfUnE9VNU
    http-types-0.9.1-COSfHHdOet5Sq6KAE7lWN
    network-2.6.2.1-Li0aefQhyJzUSpQ0fLiXL unix-2.7.2.0
    unix-time-0.3.6-6bZ4vlHgZbL8E5DKeI2fRH
    wai-3.2.1.1-FhGbGXgEdLG73fMsfll74t
haddock-interfaces: /usr/share/doc/haskell-wai-logger/html/wai-logger.haddock
haddock-html: /usr/share/doc/haskell-wai-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
